--
-- OrganizedPanicAuraIcon
--
-- Copyright (c) 2021 Dana Basken
--

local _, NS = ...

local AceEvent = LibStub("AceEvent-3.0")

OrganizedPanicAuraIcon = {}
OrganizedPanicAuraIcon.__index = OrganizedPanicAuraIcon

local ICON_SIZE = 12

function OrganizedPanicAuraIcon:Create(aura, parentFrame)
  local instance = {}
  setmetatable(instance, OrganizedPanicAuraIcon)
  instance:Construct(aura, parentFrame)
  return instance
end

function OrganizedPanicAuraIcon:Construct(aura, parentFrame)
  self.aura = aura
  self.parentFrame = parentFrame
  self:CreateUI()
  self:RefreshUI()
end

function OrganizedPanicAuraIcon:CreateUI()
  self.frame = CreateFrame("Frame", "$parentAuraIcon", self.parentFrame, BackdropTemplateMixin and "BackdropTemplate")
  self.frame:SetWidth(ICON_SIZE)
  self.frame:SetHeight(ICON_SIZE)
  self.frame:SetPoint("TOPLEFT", 0, 0)
  self.frame.texture = self.frame:CreateTexture()
  self.frame.texture:SetTexture(self.aura.icon)
  self.frame.texture:SetAllPoints()
end

function OrganizedPanicAuraIcon:RefreshUI()
  NS:trace("RefreshUI", self.aura.name, self.aura.state, self.aura.icon)
  if self.aura.state == "ON" then
    if NS.db.profile.windowLocked then
      self.frame:SetAlpha(0.5)
    else
      self.frame:SetAlpha(1)
    end
    self.frame:Show()
  end
  if self.aura.state == "OFF" then
    self.frame:Hide()
  end
end

function OrganizedPanicAuraIcon:SetPosition(x, y)
  self.frame:SetPoint("TOPLEFT", self.parentFrame, x, -y)
end
