--
-- OrganizedPanicMinimapIcon
--
-- Copyright (c) 2021 Dana Basken
--

local _, NS = ...

OrganizedPanicMinimapIcon = {}
OrganizedPanicMinimapIcon.__index = OrganizedPanicMinimapIcon

function OrganizedPanicMinimapIcon:Create(id, icon, db, onLeftClick)
  local instance = {}
  setmetatable(instance, OrganizedPanicMinimapIcon)
  instance:Construct(id, icon, db, onLeftClick)
  return instance
end

function OrganizedPanicMinimapIcon:Construct(id, icon, db, onLeftClick)

  self.id = id
  self.db = db
  self.onLeftClick = onLeftClick

  self.dataBroker = LibStub("LibDataBroker-1.1"):NewDataObject(self.id, {
    type = "data source",
    text = id,
    icon = icon,
    OnTooltipShow = function(tooltip)
      tooltip:SetText(NS.ADDON_TITLE)
      tooltip:AddLine("left-click: show/hide window", 1, 1, 1)
      tooltip:Show()
    end,
    OnEnter = function() self:OnEnter() end,
    OnLeave = function() self:OnLeave() end,
    OnClick = function(_, button) self:OnClick(button) end
  })

  self.icon = LibStub("LibDBIcon-1.0")
  self.icon:Register(self.id, self.dataBroker, self.db.profile.minimap)

end

function OrganizedPanicMinimapIcon:OnEnter()
  -- TODO: show info frame
end

function OrganizedPanicMinimapIcon:OnLeave()
  -- TODO: hide info frame
end

function OrganizedPanicMinimapIcon:OnClick(button)
  if button == "LeftButton" then
    self.onLeftClick()
  end
  if button == "RightButton" then
    -- TODO: menu
  end
end

function OrganizedPanicMinimapIcon:UpdateVisibility()
  if self.db.profile.minimap.hide then
    self:Hide()
  else
    self:Show()
  end
end

function OrganizedPanicMinimapIcon:Show()
  self.icon:Show(self.id)
  self.db.profile.minimap.hide = false
end

function OrganizedPanicMinimapIcon:Hide()
  self.icon:Hide(self.id)
  self.db.profile.minimap.hide = true
end

function OrganizedPanicMinimapIcon:Toggle()
  if self.db.profile.minimap.hide then
    self:Show()
  else
    self:Hide()
  end
end
