local _, NS = ...

local L = LibStub("AceLocale-3.0"):GetLocale(NS.ADDON_NAME)

function NS:BuildOptions(name, addon)
  return {
    name = name,
    handler = addon,
    type = "group",
    set = "SetOption",
    get = "GetOption",
    args = {
      description = {
        order = 1,
        type = "description",
        name = L["OrganizedPanic helps your party members avoid casting expensive cooldowns at the same time."]
      },
      minimap_settings = {
        order = 2,
        type = "group",
        name = L["Minimap Settings"],
        inline = true,
        args = {
          group_2 = {
            order = 3,
            type = "group",
            name = "",
            inline = true,
            args = {
              special_recipes_only = {
                order = 2,
                type = "toggle",
                name = L["Show Minimap Icon"],
                desc = L["Show or hide the minimap icon."],
                set = "SetMimimapVisible",
                get = "GetMimimapVisible"
              },
            }
          },
        },
      },
      display_settings = {
        order = 3,
        type = "group",
        name = L["Display Settings"],
        inline = true,
        args = {
          help = {
            type = "description",
            name = L["The display of the flashing border can be customized by changing the options below."],
            order = 1,
          },
          flash_border = {
            order = 2,
            type = "toggle",
            name = L["Flash Border"],
            desc = L["Flash border when another player casts a cooldown?"],
            arg = "flashBorder",
          },
          border_color = {
            order = 3,
            type = "color",
            name = L["Border color"],
            desc = L["The color of the flashing border."],
            set = "SetBorderColor",
            get = "GetBorderColor"
          },
        }
      },
      window_settings = {
        order = 3,
        type = "group",
        name = L["Window Settings"],
        inline = true,
        args = {
          help = {
            type = "description",
            name = L["Window settings can be customized by changing the options below."],
            order = 1,
          },
          auto_show_hide = {
            order = 2,
            type = "toggle",
            name = L["Auto Show/Hide"],
            desc = L["Automatically show and hide the window when grouped?"],
            arg = "autoShowHide",
          },
        }
      },
      sound_settings = {
        order = 4,
        type = "group",
        name = L["Sound Settings"],
        inline = true,
        args = {
          help = {
            order = 1,
            type = "description",
            name = L["Sounds can be customized by changing the options below."],
          },
          play_sound = {
            order = 2,
            type = "toggle",
            name = L["Play Sounds"],
            desc = L["Play alert sounds when a cooldown or buff is cast?"],
            arg = "playSound",
          },
          sound_select = {
            order = 3,
            type = "select",
            name = L["Panic Sound"],
            desc = L["The sound to play when another player casts a cooldown."],
            arg = "sound",
            validate = function(info, value) info.handler:PlaySound(NS.SOUNDS[value]); return true end,
            values = function(info) return info.handler:GetSoundOptions() end,
            sorting = function(info) return info.handler:GetSoundOptionsSort() end
          },
          buff_sound_select = {
            order = 4,
            type = "select",
            name = L["Buff Sound"],
            desc = L["The sound to play when another player casts a buff."],
            arg = "buffSound",
            validate = function(info, value) info.handler:PlaySound(NS.SOUNDS[value]); return true end,
            values = function(info) return info.handler:GetSoundOptions() end,
            sorting = function(info) return info.handler:GetSoundOptionsSort() end
          },
        },
      },
      test_group = {
        order = 5,
        type = "group",
        name = L["Testing"],
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              test_sound = {
                type = "execute",
                order = 1,
                name = L["Panic!"],
                desc = L["Test the sound and flash."],
                func = function(info) info.handler:Panic() end
              },
            },
          },
        },
      },
      include_group = {
        order = 6,
        type = "group",
        name = L["Inclusion"],
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              include_self_toggle = {
                order = 1,
                type = "toggle",
                name = L["Include Self"],
                desc = L["Include self when warning about casts?"],
                arg = "includeSelf",
              },
              include_role_toggle = {
                order = 2,
                type = "toggle",
                name = L["Include Role Only"],
                desc = L["Include spells from my role only?"],
                arg = "includeRole",
              },
              include_minor_toggle = {
                order = 2,
                type = "toggle",
                name = L["Include Minor Panics"],
                desc = L["Include panics that aren't large group-wide spells?"],
                arg = "includeMinorPanics",
              },
            },
          },
        },
      },
      about_group = {
        order = 7,
        type = "group",
        name = "",
        inline = true,
        args = {
          version_description = {
            order = 1,
            type = "description",
            name = function() return ("  %s: v%s by Baernklaw of Knights of the Night"):format(NS.ADDON_NAME, NS.VERSION) end,
          },
        },
      },
    }
  }
end
